Function of one (deltamethod) or more arguments, expressed
in raw form (e.g. a*x/(b+x))
z
numeric vector of values
var
variable name
vars
list of variable names
params
list or named numeric vector of parameter values to substitute
meanval
possibly named vector of mean values of parameters
Sigma
numeric vector of variances or variance-covariance matrix
max.order
maximum order of delta method to compute
verbose
print details?
Value
For deltavar(), a vector of predicted variances; for
deltamethod() a vector containing the observed value of the
function average, the function applied to the average, and a series of
delta-method approximations
Details
deltamethod() is for computing delta-method approximations of
the mean of a function of data; deltavar() is for estimating
variances of a function based on the mean values and
variance-covariance matrix of the parameters. If Sigma is a
vector, the parameters are assumed to be independently estimated.
References
Lyons (1991), "A practical guide to data analysis for
physical science students", Cambridge University Press